==> nanolight-1.6.4.tgz: package/nanolight.js <==
/* ISC (c) 2018+ Jackens * https://github.com/jackens/nanolight */

if (typeof window !== 'undefined') {
  window['module.exports'] = window['module.exports'] || {}
  window.require = window.require || function (id) { return window['module.exports'][id] }
}

(function () {
  var R = /("(?:.|\n)*?")|('(?:.|\n)*?')|(`(?:.|\n)*?`)|(\/\*(?:.|\n)*?\*\/)|(<!--(?:.|\n)*?-->)|(\/\/.*?\n)|(\d+(?:\.\d+)?)|(!|\$|%|&|\(|\)|\*|\+|,|-|\.|\/|:|;|<|=|>|\?|@|\[|\\|\]|\^|_|\{|\||\}|~)|([a-zA-Z_]\w+)/
  var N = 'nanolight'
  var C = N + '-char ' + N + '-char-'
  var X = '<span class="'
  var Y = '">'
  var Z = '</span>'

  function E (e) {
    return e.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;')
  }

  function F (e, i, a, s, c) {
    if (i % 10) { return }
    a = a.slice(i)
    s = a[1] || a[2] || a[3]
    c = a[4] || a[5] || a[6]
    e = E(e)
    return (s ? [e, X, C, H(s), Y, E(s[0]), Z, X, N, '-string', Y, E(s.substr(1, s.length - 2)), Z, X, C, H(s), Y, E(s[0]), Z] : c ? [e, X, N, '-comment', Y, E(c), Z] : a[7] ? [e, X, N, '-number', Y, a[7], Z] : a[8] ? [e, X, C, H(a[8]), Y, E(a[8]), Z] : a[9] ? [e, X, N, '-word ', N, '-word-', a[9], Y, a[9], Z] : [e]).join('')
  }

  function H (c) {
    return c.charCodeAt(0).toString(16)
  }

  var nanolight = function (code) {
    return code.split(R).map(F).join('')
  }

  nanolight.cls = function (cls) {
    var a = document.getElementsByClassName(cls || N)
    for (var i = 0; i < a.length; i++) {
      a[i].innerHTML = this(a[i].innerText)
    }
  }

  if (typeof module !== 'undefined') {
    module.exports = nanolight
  } else if (typeof window !== 'undefined') {
    window['module.exports']['nanolight'] = nanolight
  }
})()

==> nanolight-1.6.7.tgz: package/nanolight.js <==
/* ISC (c) 2018+ Jackens * https://github.com/jackens/nanolight */

if (typeof window !== 'undefined') {
  window['module.exports'] = window['module.exports'] || {}
  window.require = window.require || function (id) { return window['module.exports'][id] }
}

(function () {
  var R = /(".*?(?:[^\\]|\\\\)?")|('.*?(?:[^\\]|\\\\)?')|(`(?:.|\n)*?(?:[^\\]|\\\\)?`)|(\/\*(?:.|\n)*?\*\/)|(<!--(?:.|\n)*?-->)|(\/\/.*?\n)|(\d+(?:\.\d+)?)|(!|\$|%|&|\(|\)|\*|\+|,|-|\.|\/|:|;|<|=|>|\?|@|\[|\\|\]|\^|_|\{|\||\}|~)|([a-zA-Z_]\w+)/
  var N = 'nanolight'
  var C = N + '-char ' + N + '-char-'
  var X = '<span class="'
  var Y = '">'
  var Z = '</span>'

  function E (e) {
    return e.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;')
  }

  function F (e, i, a, s, c) {
    if (i % 10) { return }
    a = a.slice(i)
    s = a[1] || a[2] || a[3]
    c = a[4] || a[5] || a[6]
    e = E(e)
    return (s ? [e, X, C, H(s), Y, E(s[0]), Z, X, N, '-string', Y, E(s.substr(1, s.length - 2)), Z, X, C, H(s), Y, E(s[0]), Z] : c ? [e, X, N, '-comment', Y, E(c), Z] : a[7] ? [e, X, N, '-number', Y, a[7], Z] : a[8] ? [e, X, C, H(a[8]), Y, E(a[8]), Z] : a[9] ? [e, X, N, '-word ', N, '-word-', a[9], Y, a[9], Z] : [e]).join('')
  }

  function H (c) {
    return c.charCodeAt(0).toString(16)
  }

  var nanolight = function (code) {
    return code.split(R).map(F).join('')
  }

  nanolight.cls = function (cls) {
    var a = document.getElementsByClassName(cls || N)
    for (var i = 0; i < a.length; i++) {
      a[i].innerHTML = this(a[i].innerText)
    }
  }

  if (typeof module !== 'undefined') {
    module.exports = nanolight
  } else if (typeof window !== 'undefined') {
    window['module.exports']['nanolight'] = nanolight
  }
})()
